@@ -28,6 +28,9 @@ static crispy_t crispy_s = {
 	.hires = 1,
 	.smoothscaling = 1,
 	.soundfix = 1,
+#ifdef CRISPY_TRUECOLOR
+	.truecolor = 1,
+#endif
 	.vsync = 1,
 };
 crispy_t *const crispy = &crispy_s;
