@@ -74,7 +74,7 @@ typedef struct
 	int soundfull;
 	int soundmono;
 	int translucency;
-#if CRISPY_TRUECOLOR
+#ifdef CRISPY_TRUECOLOR
 	int truecolor;
 #endif
 	int uncapped;
@@ -222,4 +222,14 @@ enum
     NUM_WIDGETS
 };
 
+enum
+{
+    RATIO_4_3,
+    RATIO_MATCH_SCREEN,
+    RATIO_16_10,
+    RATIO_16_9,
+    RATIO_21_9,
+    NUM_RATIOS
+};
+
 #endif
