@@ -1875,7 +1875,9 @@ void D_DoomMain (void)
     // [crispy] allow overriding of special-casing
     if (!M_ParmExists("-noautoload") && gamemode != shareware)
     {
-	if (gamemode == retail && gameversion == exe_ultimate)
+	if (gamemode == retail &&
+	    gameversion == exe_ultimate &&
+	    gamevariant != freedoom)
 	{
 		D_LoadSigilWad();
 	}
