@@ -70,22 +70,10 @@
 #define HU_INPUTWIDTH	64
 #define HU_INPUTHEIGHT	1
 
-#define HU_COORDX	((ORIGWIDTH - 7 * hu_font['A'-HU_FONTSTART]->width) + WIDESCREENDELTA)
+#define HU_COORDX	((ORIGWIDTH - 8 * hu_font['A'-HU_FONTSTART]->width) + WIDESCREENDELTA)
 
 
-char *chat_macros[10] =
-{
-    HUSTR_CHATMACRO0,
-    HUSTR_CHATMACRO1,
-    HUSTR_CHATMACRO2,
-    HUSTR_CHATMACRO3,
-    HUSTR_CHATMACRO4,
-    HUSTR_CHATMACRO5,
-    HUSTR_CHATMACRO6,
-    HUSTR_CHATMACRO7,
-    HUSTR_CHATMACRO8,
-    HUSTR_CHATMACRO9
-};
+char *chat_macros[10];
 
 const char *player_names[] =
 {
@@ -412,7 +400,7 @@ const char *mapnames_commercial[] =
     MHUSTR_21
 };
 
-static void CrispyReplaceColor (char *str, const int cr, const char *col)
+static void CrispyReplaceColor (const char *str, const int cr, const char *col)
 {
     char *str_replace, col_replace[16];
 
@@ -728,7 +716,10 @@ void HU_Start(void)
 
     // [crispy] explicitely display (episode and) map if the
     // map is from a PWAD or if the map title string has been dehacked
-    if (DEH_HasStringReplacement(s) || (!W_IsIWADLump(maplumpinfo) && (!nervewadfile || gamemission != pack_nerve)))
+    if (DEH_HasStringReplacement(s) ||
+        (!W_IsIWADLump(maplumpinfo) &&
+        !(crispy->havenerve && gamemission == pack_nerve) &&
+        !(crispy->havemaster && gamemission == pack_master)))
     {
 	char *m;
 
@@ -833,6 +824,12 @@ void HU_Drawer(void)
 	return;
     }
 
+    // [crispy] re-calculate widget coordinates on demand
+    if (hu_widescreendelta != WIDESCREENDELTA)
+    {
+        HU_Start();
+    }
+
     // [crispy] translucent messages for translucent HUD
     if (screenblocks >= CRISPY_HUD && (screenblocks % 3 == 2) && (!automapactive || crispy->automapoverlay))
 	dp_translucent = true;
@@ -869,7 +866,8 @@ void HU_Drawer(void)
 	HUlib_drawTextLine(&w_scrts, false);
     }
 
-    if (crispy->leveltime == WIDGETS_ALWAYS || (automapactive && crispy->leveltime == WIDGETS_AUTOMAP))
+    if (crispy->leveltime == WIDGETS_ALWAYS || (automapactive && crispy->leveltime == WIDGETS_AUTOMAP) ||
+        (crispy->btusetimer && plr->btuse_tics))
     {
 	HUlib_drawTextLine(&w_ltime, false);
     }
@@ -935,12 +933,6 @@ void HU_Ticker(void)
     char c;
     char str[32], *s;
 
-    // [crispy] re-calculate widget coordinates on demand
-    if (hu_widescreendelta != WIDESCREENDELTA)
-    {
-        HU_Start();
-    }
-
     // tick down message counter if message is up
     if (message_counter && !--message_counter)
     {
@@ -1079,6 +1071,21 @@ void HU_Ticker(void)
 	    HUlib_addCharToTextLine(&w_ltime, *(s++));
     }
 
+    // [crispy] "use" button timer overrides the level time widget
+    if (crispy->btusetimer && plr->btuse_tics)
+    {
+	const int mins = plr->btuse / (60 * TICRATE);
+	const float secs = (float)(plr->btuse % (60 * TICRATE)) / TICRATE;
+
+	plr->btuse_tics--;
+
+	M_snprintf(str, sizeof(str), "%sU %02i:%05.02f", crstr[CR_GRAY], mins, secs);
+	HUlib_clearTextLine(&w_ltime);
+	s = str;
+	while (*s)
+	    HUlib_addCharToTextLine(&w_ltime, *(s++));
+    }
+
     if (crispy->playercoords == WIDGETS_ALWAYS || (automapactive && crispy->playercoords == WIDGETS_AUTOMAP))
     {
 	M_snprintf(str, sizeof(str), "%sX %s%-5d", cr_stat2, crstr[CR_GRAY],
