@@ -1236,6 +1236,9 @@ void M_MusicVol(int choice)
 //
 void M_DrawMainMenu(void)
 {
+    // [crispy] force status bar refresh
+    inhelpscreens = true;
+
     V_DrawPatchDirect(94, 2,
                       W_CacheLumpName(DEH_String("M_DOOM"), PU_CACHE));
 }
@@ -1248,6 +1251,9 @@ void M_DrawMainMenu(void)
 //
 void M_DrawNewGame(void)
 {
+    // [crispy] force status bar refresh
+    inhelpscreens = true;
+
     V_DrawPatchDirect(96, 14, W_CacheLumpName(DEH_String("M_NEWG"), PU_CACHE));
     V_DrawPatchDirect(54, 38, W_CacheLumpName(DEH_String("M_SKILL"), PU_CACHE));
 }
@@ -1282,6 +1288,9 @@ int     epi;
 
 void M_DrawEpisode(void)
 {
+    // [crispy] force status bar refresh
+    inhelpscreens = true;
+
     V_DrawPatchDirect(54, 38, W_CacheLumpName(DEH_String("M_EPISOD"), PU_CACHE));
 }
 
@@ -1480,7 +1489,7 @@ static void M_DrawCrispness1(void)
 
     M_DrawCrispnessSeparator(crispness_sep_rendering, "Rendering");
     M_DrawCrispnessItem(crispness_hires, "High Resolution Rendering", crispy->hires, true);
-    M_DrawCrispnessItem(crispness_widescreen, "Widescreen Rendering", crispy->widescreen, aspect_ratio_correct);
+    M_DrawCrispnessMultiItem(crispness_widescreen, "Widescreen Aspect Ratio", multiitem_widescreen, crispy->widescreen, aspect_ratio_correct);
     M_DrawCrispnessItem(crispness_uncapped, "Uncapped Framerate", crispy->uncapped, true);
     M_DrawCrispnessItem(crispness_vsync, "Enable VSync", crispy->vsync, !force_software_renderer);
     M_DrawCrispnessItem(crispness_smoothscaling, "Smooth Pixel Scaling", crispy->smoothscaling, true);
@@ -2389,13 +2398,13 @@ boolean M_Responder (event_t* ev)
 	    if (mousebprevweapon >= 0 && ev->data1 & (1 << mousebprevweapon))
 	    {
 		key = key_menu_down;
-		mousewait = I_GetTime() + 5;
+		mousewait = I_GetTime() + 1;
 	    }
 	    else
 	    if (mousebnextweapon >= 0 && ev->data1 & (1 << mousebnextweapon))
 	    {
 		key = key_menu_up;
-		mousewait = I_GetTime() + 5;
+		mousewait = I_GetTime() + 1;
 	    }
 	}
 	else
@@ -3124,8 +3133,15 @@ void M_Init (void)
         int i;
 
         NewDef.prevMenu = &EpiDef;
-        EpisodeMenu[0].alphaKey = 'h';
-        EpisodeMenu[0].alttext = "Hell on Earth";
+        EpisodeMenu[0].alphaKey = gamevariant == freedm ||
+                                  gamevariant == freedoom ?
+                                 'f' :
+                                 'h';
+        EpisodeMenu[0].alttext = gamevariant == freedm ?
+                                 "FreeDM" :
+                                 gamevariant == freedoom ?
+                                 "Freedoom: Phase 2" :
+                                 "Hell on Earth";
         EpiDef.numitems = 1;
 
         if (crispy->havenerve)
