@@ -981,13 +981,12 @@ void P_MovePsprites (player_t* player)
 {
     int		i;
     pspdef_t*	psp;
-    state_t*	state;
 	
     psp = &player->psprites[0];
     for (i=0 ; i<NUMPSPRITES ; i++, psp++)
     {
 	// a null state means not active
-	if ( (state = psp->state) )	
+	if (psp->state)
 	{
 	    // drop tic count and possibly change state
 
@@ -1006,6 +1005,8 @@ void P_MovePsprites (player_t* player)
 
     // [crispy] apply bobbing (or centering) to the player's weapon sprite
     psp = &player->psprites[0];
+    psp->sx2 = psp->sx;
+    psp->sy2 = psp->sy;
     if (psp->state)
     {
 	// [crispy] don't center vertically during lowering and raising states
@@ -1013,8 +1014,6 @@ void P_MovePsprites (player_t* player)
 	    psp->state->action.acp3 == (actionf_p3)A_Lower ||
 	    psp->state->action.acp3 == (actionf_p3)A_Raise)
 	{
-		psp->sx2 = psp->sx;
-		psp->sy2 = psp->sy;
 	}
 	else
 	// [crispy] not attacking means idle
@@ -1034,11 +1033,6 @@ void P_MovePsprites (player_t* player)
 		psp->sy2 = WEAPONTOP;
 	}
     }
-    else
-    {
-	psp->sx2 = psp->sx;
-	psp->sy2 = psp->sy;
-    }
 
 	// [crispy] squat down weapon sprite a bit after hitting the ground
 	if (player->psp_dy_max)
