@@ -222,12 +222,17 @@ void P_LoadSegs (int lump)
 	li->linedef = ldef;
 	side = SHORT(ml->side);
 
-        // e6y: check for wrong indexes
-        if ((unsigned)ldef->sidenum[side] >= (unsigned)numsides)
-        {
-            I_Error("P_LoadSegs: linedef %d for seg %d references a non-existent sidedef %d",
-                    linedef, i, (unsigned)ldef->sidenum[side]);
-        }
+	// e6y: check for wrong indexes
+	if ((unsigned)linedef >= (unsigned)numlines)
+	{
+		I_Error("P_LoadSegs: seg %d references a non-existent linedef %d",
+			i, (unsigned)linedef);
+	}
+	if ((unsigned)ldef->sidenum[side] >= (unsigned)numsides)
+	{
+		I_Error("P_LoadSegs: linedef %d for seg %d references a non-existent sidedef %d",
+			linedef, i, (unsigned)ldef->sidenum[side]);
+	}
 
 	li->sidedef = &sides[ldef->sidenum[side]];
 	li->frontsector = sides[ldef->sidenum[side]].sector;
@@ -1036,8 +1041,7 @@ const char *skilltable[] =
 // [crispy] factor out map lump name and number finding into a separate function
 int P_GetNumForMap (int episode, int map, boolean critical)
 {
-    char	lumpname[9];
-    int		lumpnum;
+    char lumpname[9];
 
     // find map name
     if ( gamemode == commercial)
@@ -1058,16 +1062,21 @@ int P_GetNumForMap (int episode, int map, boolean critical)
 
     // [crispy] special-casing for E1M10 "Sewers" support
     if (crispy->havee1m10 && episode == 1 && map == 10)
-	DEH_snprintf(lumpname, 9, "E1M10");
-
-    lumpnum = critical ? W_GetNumForName (lumpname) : W_CheckNumForName (lumpname);
-
-    if (nervewadfile && episode != 2 && map <= 9)
     {
-        lumpnum = W_CheckNumForNameFromTo (lumpname, lumpnum - 1, 0);
+	DEH_snprintf(lumpname, 9, "E1M10");
     }
 
-    return lumpnum;
+    // [crispy] NRFTL / The Master Levels
+    if (crispy->havenerve && episode == 2 && map <= 9)
+    {
+	strcat(lumpname, "N");
+    }
+    if (crispy->havemaster && episode == 3 && map <= 21)
+    {
+	strcat(lumpname, "M");
+    }
+
+    return critical ? W_GetNumForName(lumpname) : W_CheckNumForName(lumpname);
 }
 
 // pointer to the current map lump info struct
@@ -1099,10 +1108,15 @@ P_SetupLevel
 	    = players[i].itemcount = 0;
     }
 
-    // [crispy] No Rest for the Living ...
-    if (nervewadfile)
+    // [crispy] NRFTL / The Master Levels
+    if (crispy->havenerve || crispy->havemaster)
     {
-        if (episode == 2)
+        if (crispy->havemaster && episode == 3)
+        {
+            gamemission = pack_master;
+        }
+        else
+        if (crispy->havenerve && episode == 2)
         {
             gamemission = pack_nerve;
         }
@@ -1113,6 +1127,11 @@ P_SetupLevel
     }
     else
     {
+        if (gamemission == pack_master)
+        {
+            episode = gameepisode = 3;
+        }
+        else
         if (gamemission == pack_nerve)
         {
             episode = gameepisode = 2;
@@ -1283,36 +1302,6 @@ P_SetupLevel
 
 }
 
-// [crispy] height of the spawnstate's first sprite in pixels
-static void P_InitActualHeights (void)
-{
-	int i;
-
-	for (i = 0; i < NUMMOBJTYPES; i++)
-	{
-		state_t *state;
-		spritedef_t *sprdef;
-		spriteframe_t *sprframe;
-		int lump;
-		patch_t *patch;
-
-		state = &states[mobjinfo[i].spawnstate];
-		sprdef = &sprites[state->sprite];
-
-		if (!sprdef->numframes || !(mobjinfo[i].flags & (MF_SOLID|MF_SHOOTABLE)))
-		{
-			mobjinfo[i].actualheight = mobjinfo[i].height;
-			continue;
-		}
-
-		sprframe = &sprdef->spriteframes[state->frame & FF_FRAMEMASK];
-		lump = sprframe->lump[0];
-		patch = W_CacheLumpNum (lump + firstspritelump, PU_CACHE);
-
-		// [crispy] round to the next integer multiple of 8
-		mobjinfo[i].actualheight = ((patch->height + 7) & (~7)) << FRACBITS;
-	}
-}
 
 
 //
@@ -1323,7 +1312,6 @@ void P_Init (void)
     P_InitSwitchList ();
     P_InitPicAnims ();
     R_InitSprites (sprnames);
-    P_InitActualHeights();
 }
 
 
