@@ -127,7 +127,7 @@ STlib_drawNum
 	I_Error("drawNum: n->y - ST_Y < 0");
 
     if (screenblocks < CRISPY_HUD || (automapactive && !crispy->automapoverlay))
-    V_CopyRect(x, n->y - ST_Y, st_backing_screen, w*numdigits, h, x, n->y);
+    V_CopyRect(x + WIDESCREENDELTA, n->y - ST_Y, st_backing_screen, w*numdigits, h, x + WIDESCREENDELTA, n->y);
 
     // if non-number, do not draw it
     if (num == 1994)
@@ -176,6 +176,9 @@ STlib_initPercent
 {
     STlib_initNum(&p->n, x, y, pl, num, on, 3);
     p->p = percent;
+
+    // [crispy] remember previous colorization
+    p->oldtranslation = NULL;
 }
 
 
@@ -186,6 +189,12 @@ STlib_updatePercent
 ( st_percent_t*		per,
   int			refresh )
 {
+    // [crispy] remember previous colorization
+    if (per->oldtranslation != dp_translation)
+    {
+        refresh = true;
+        per->oldtranslation = dp_translation;
+    }
 
     STlib_updateNum(&per->n, refresh); // [crispy] moved here
 
@@ -244,7 +253,7 @@ STlib_updateMultIcon
 		I_Error("updateMultIcon: y - ST_Y < 0");
 
 	    if (screenblocks < CRISPY_HUD || (automapactive && !crispy->automapoverlay))
-	    V_CopyRect(x, y-ST_Y, st_backing_screen, w, h, x, y);
+	    V_CopyRect(x + WIDESCREENDELTA, y-ST_Y, st_backing_screen, w, h, x + WIDESCREENDELTA, y);
 	}
 	V_DrawPatch(mi->x, mi->y, mi->p[*mi->inum]);
 	mi->oldinum = *mi->inum;
@@ -297,7 +306,7 @@ STlib_updateBinIcon
 	    V_DrawPatch(bi->x, bi->y, bi->p);
 	else
 	    if (screenblocks < CRISPY_HUD || (automapactive && !crispy->automapoverlay))
-	    V_CopyRect(x, y-ST_Y, st_backing_screen, w, h, x, y);
+	    V_CopyRect(x + WIDESCREENDELTA, y-ST_Y, st_backing_screen, w, h, x + WIDESCREENDELTA, y);
 
 	bi->oldval = *bi->val;
     }
