@@ -497,12 +497,36 @@ void ST_refreshBackground(boolean force)
 		{
 			for (x = 0; x < SCREENWIDTH; x++)
 			{
+#ifndef CRISPY_TRUECOLOR
 				*dest++ = src[((y&63)<<6) + (x&63)];
+#else
+				*dest++ = colormaps[src[((y&63)<<6) + (x&63)]];
+#endif
+			}
+		}
+
+		// [crispy] preserve bezel bottom edge
+		if (scaledviewwidth == SCREENWIDTH)
+		{
+			patch_t *const patch = W_CacheLumpName(DEH_String("brdr_b"), PU_CACHE);
+
+			for (x = 0; x < WIDESCREENDELTA; x += 8)
+			{
+				V_DrawPatch(x - WIDESCREENDELTA, 0, patch);
+				V_DrawPatch(ORIGWIDTH + WIDESCREENDELTA - x - 8, 0, patch);
 			}
 		}
 	}
 
-	V_DrawPatch(ST_X, 0, sbar);
+	// [crispy] center unity rerelease wide status bar
+	if (sbar->width > ORIGWIDTH && sbar->leftoffset == 0)
+	{
+	    V_DrawPatch(ST_X + (ORIGWIDTH - sbar->width) / 2, 0, sbar);
+	}
+	else
+	{
+	    V_DrawPatch(ST_X, 0, sbar);
+	}
 
 	// draw right side of bar if needed (Doom 1.0)
 	if (sbarr)
@@ -520,7 +544,14 @@ void ST_refreshBackground(boolean force)
 	// [crispy] copy entire SCREENWIDTH, to preserve the pattern
 	// to the left and right of the status bar in widescren mode
 	if (!force)
-	V_CopyRect(ST_X, 0, st_backing_screen, SCREENWIDTH >> crispy->hires, ST_HEIGHT, ST_X, ST_Y);
+	{
+	    V_CopyRect(ST_X, 0, st_backing_screen, SCREENWIDTH >> crispy->hires, ST_HEIGHT, ST_X, ST_Y);
+	}
+	else if (WIDESCREENDELTA > 0 && !st_firsttime)
+	{
+	    V_CopyRect(0, 0, st_backing_screen, WIDESCREENDELTA, ST_HEIGHT, 0, ST_Y);
+	    V_CopyRect(ORIGWIDTH + WIDESCREENDELTA, 0, st_backing_screen, WIDESCREENDELTA, ST_HEIGHT, ORIGWIDTH + WIDESCREENDELTA, ST_Y);
+	}
     }
 
 }
