@@ -28,11 +28,14 @@
 #define ORIGWIDTH  320 // [crispy]
 #define ORIGHEIGHT 200 // [crispy]
 
-#define MAXWIDTH  (ORIGWIDTH << 1) // [crispy]
+#define MAXWIDTH  (ORIGWIDTH << 2) // [crispy]
 #define MAXHEIGHT (ORIGHEIGHT << 1) // [crispy]
 
 extern int SCREENWIDTH;
 extern int SCREENHEIGHT;
+extern int NONWIDEWIDTH; // [crispy] non-widescreen SCREENWIDTH
+extern int WIDESCREENDELTA; // [crispy] horizontal widescreen offset
+void I_GetScreenDimensions (void); // [crispy] re-calculate WIDESCREENDELTA
 
 // Screen height used when aspect_ratio_correct=true.
 
