@@ -61,6 +61,7 @@ void BindCompatibilityVariables(void)
         M_BindIntVariable("crispy_automaprotate",   &crispy->automaprotate);
         M_BindIntVariable("crispy_automapstats",    &crispy->automapstats);
         M_BindIntVariable("crispy_bobfactor",       &crispy->bobfactor);
+        M_BindIntVariable("crispy_btusetimer",      &crispy->btusetimer);
         M_BindIntVariable("crispy_brightmaps",      &crispy->brightmaps);
         M_BindIntVariable("crispy_centerweapon",    &crispy->centerweapon);
         M_BindIntVariable("crispy_coloredblood",    &crispy->coloredblood);
@@ -88,6 +89,7 @@ void BindCompatibilityVariables(void)
         M_BindIntVariable("crispy_recoil",          &crispy->recoil);
         M_BindIntVariable("crispy_secretmessage",   &crispy->secretmessage);
         M_BindIntVariable("crispy_smoothlight",     &crispy->smoothlight);
+        M_BindIntVariable("crispy_smoothmap",       &crispy->smoothmap);
         M_BindIntVariable("crispy_smoothscaling",   &crispy->smoothscaling);
         M_BindIntVariable("crispy_soundfix",        &crispy->soundfix);
         M_BindIntVariable("crispy_soundfull",       &crispy->soundfull);
