@@ -50,7 +50,8 @@ static int *controls[] = { &key_left, &key_right, &key_up, &key_down,
                            &key_weapon7, &key_weapon8,
                            &key_arti_quartz, &key_arti_urn, &key_arti_bomb,
                            &key_arti_tome, &key_arti_ring, &key_arti_chaosdevice,
-                           &key_arti_shadowsphere, &key_arti_wings, &key_arti_torch,
+                           &key_arti_shadowsphere, &key_arti_wings, 
+                           &key_arti_torch, &key_arti_morph,
                            &key_arti_all, &key_arti_health, &key_arti_poisonbag,
                            &key_arti_blastradius, &key_arti_teleport,
                            &key_arti_teleportother, &key_arti_egg,
@@ -237,7 +238,11 @@ static void ConfigExtraKeys(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(unused))
         AddKeyControl(table, "Look down", &key_lookdown);
         AddKeyControl(table, "Center view", &key_lookcenter);
 
-        AddSectionLabel(table, "Movement", true);
+        AddSectionLabel(table, "Movement", false);
+        AddKeyControl(table, "Move Forward (alt.)", &key_alt_up);
+        AddKeyControl(table, "Move Backward (alt.)", &key_alt_down);
+        AddKeyControl(table, "Strafe Left (alt.)", &key_alt_strafeleft);
+        AddKeyControl(table, "Strafe Right (alt.)", &key_alt_straferight);
         AddKeyControl(table, "Toggle always run", &key_toggleautorun);
         AddKeyControl(table, "Toggle vert. mouse", &key_togglenovert);
         }
@@ -298,6 +303,7 @@ static void ConfigExtraKeys(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(unused))
             AddKeyControl(table, "Shadowsphere", &key_arti_shadowsphere);
             AddKeyControl(table, "Wings of Wrath", &key_arti_wings);
             AddKeyControl(table, "Torch", &key_arti_torch);
+            AddKeyControl(table, "Morph Ovum", &key_arti_morph);
         }
 
         if (gamemission == hexen)
