@@ -224,7 +224,7 @@ static void SetMission(mission_config_t *config)
     M_SetConfigFilenames(config->config_file, config->extra_config_file);
 }
 
-static mission_config_t *GetMissionForName(char *name)
+static mission_config_t *GetMissionForName(const char *name)
 {
     int i;
 
@@ -293,7 +293,7 @@ static void OpenGameSelectDialog(GameSelectCallback callback)
         // Do we have any IWADs for this game installed?
         // If so, add a button.
 
-        iwads = D_FindAllIWADs(mission_configs[i].mask);
+        iwads = D_FindAllIWADs(mission_configs[i].mask & (IWAD_MASK_DOOM|IWAD_MASK_HERETIC)); // [crispy] restrict game choice to Doom and Heretic
 
         if (iwads[0] != NULL)
         {
@@ -335,7 +335,7 @@ static void OpenGameSelectDialog(GameSelectCallback callback)
 void SetupMission(GameSelectCallback callback)
 {
     mission_config_t *config;
-    char *mission_name;
+    const char *mission_name;
     int p;
 
     //!
